@@ -13,11 +13,11 @@ mod xstr;
 
 pub use coord::Coord;
 #[cfg(feature = "json")]
-pub use hayson::{Hayson, FromHaysonError};
+pub use hayson::{FromHaysonError, Hayson};
 pub use hsref::{ParseRefError, Ref};
 pub use marker::{Marker, RemoveMarker};
 pub use na::Na;
-pub use number::{Number};
+pub use number::Number;
 pub use qname::Qname;
 pub use symbol::{ParseSymbolError, Symbol};
 pub use tag::{is_tag_name, ParseTagNameError, TagName};
