@@ -14,10 +14,7 @@ impl Xstr {
     /// let my_xstr = Xstr::new("Color".to_string(), "red".to_string());
     /// ```
     pub fn new(type_name: String, value: String) -> Self {
-        Self {
-            type_name,
-            value,
-        }
+        Self { type_name, value }
     }
 
     pub fn type_name(&self) -> &str {
@@ -38,4 +35,4 @@ impl std::fmt::Display for Xstr {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         write!(f, "{}(\"{}\")", self.type_name(), self.value())
     }
-}
\ No newline at end of file
+}
